@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2019, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2020, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -115,7 +115,7 @@ void increment_counters_from_bitmap(count_t * counters,
     }
 }
 
-#elif __PPC__
+#elif defined __PPC__
 
 void increment_counters_from_bitmap(count_t * counters,
                                     unsigned char * bitmap,
