@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2019, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2020, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -238,8 +238,8 @@ void fastq_join()
   fastq_close(fastq_fwd);
   fastq_fwd = 0;
 
-  free(seq);
-  free(qual);
-  free(padgap);
-  free(padgapq);
+  xfree(seq);
+  xfree(qual);
+  xfree(padgap);
+  xfree(padgapq);
 }
