@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2019, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2020, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -713,6 +713,10 @@ void fastx_revcomp()
       else
         snprintf(header, header_alloc, "%s", d);
 
+      hlen += suffix_length;
+
+      int64_t abundance = fastx_get_abundance(h);
+
 
       /* sequence */
 
@@ -748,7 +752,7 @@ void fastx_revcomp()
                             length,
                             header,
                             hlen,
-                            0,
+                            abundance,
                             count,
                             -1.0,
                             -1, -1, 0, 0.0);
@@ -760,7 +764,7 @@ void fastx_revcomp()
                             header,
                             hlen,
                             qual_buffer,
-                            0,
+                            abundance,
                             count,
                             -1.0);
 
@@ -804,6 +808,7 @@ void fastq_convert()
       /* header */
 
       char * header = fastq_get_header(h);
+      int64_t abundance = fastq_get_abundance(h);
 
       /* sequence */
 
@@ -819,7 +824,9 @@ void fastq_convert()
           if (q < opt_fastq_qmin)
             {
               fprintf(stderr,
-                      "\nFASTQ quality score (%d) below minimum (%" PRId64 ") in entry no %" PRIu64 " starting on line %" PRIu64 "\n",
+                      "\nFASTQ quality score (%d) below minimum (%" PRId64
+                      ") in entry no %" PRIu64
+                      " starting on line %" PRIu64 "\n",
                       q,
                       opt_fastq_qmin,
                       fastq_get_seqno(h) + 1,
@@ -829,7 +836,9 @@ void fastq_convert()
           if (q > opt_fastq_qmax)
             {
               fprintf(stderr,
-                      "\nFASTQ quality score (%d) above maximum (%" PRId64 ") in entry no %" PRIu64 " starting on line %" PRIu64 "\n",
+                      "\nFASTQ quality score (%d) above maximum (%" PRId64
+                      ") in entry no %" PRIu64
+                      " starting on line %" PRIu64 "\n",
                       q,
                       opt_fastq_qmax,
                       fastq_get_seqno(h) + 1,
@@ -850,7 +859,15 @@ void fastq_convert()
       quality[length] = 0;
 
       int hlen = fastq_get_header_length(h);
-      fastq_print_general(fp_fastqout, sequence, length, header, hlen, quality, 0, j, -1.0);
+      fastq_print_general(fp_fastqout,
+                          sequence,
+                          length,
+                          header,
+                          hlen,
+                          quality,
+                          abundance,
+                          j,
+                          -1.0);
 
       j++;
       progress_update(fastq_get_position(h));
