@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2019, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2020, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -251,7 +251,7 @@ void sintax_analyse(char * query_head,
     }
 
   /* write to tabbedout file */
-  pthread_mutex_lock(&mutex_output);
+  xpthread_mutex_lock(&mutex_output);
   fprintf(fp_tabbedout, "%s\t", query_head);
 
   queries++;
@@ -313,7 +313,7 @@ void sintax_analyse(char * query_head,
 #endif
 
   fprintf(fp_tabbedout, "\n");
-  pthread_mutex_unlock(&mutex_output);
+  xpthread_mutex_unlock(&mutex_output);
 }
 
 void sintax_query(int64_t t)
@@ -420,7 +420,7 @@ void sintax_thread_run(int64_t t)
 {
   while (1)
     {
-      pthread_mutex_lock(&mutex_input);
+      xpthread_mutex_lock(&mutex_input);
 
       if (fastx_next(query_fastx_h,
                      ! opt_notrunclabels,
@@ -468,7 +468,7 @@ void sintax_thread_run(int64_t t)
           uint64_t progress = fastx_get_position(query_fastx_h);
 
           /* let other threads read input */
-          pthread_mutex_unlock(&mutex_input);
+          xpthread_mutex_unlock(&mutex_input);
 
           /* minus strand: copy header and reverse complementary sequence */
           if (opt_strand > 1)
@@ -482,16 +482,16 @@ void sintax_thread_run(int64_t t)
           sintax_query(t);
 
           /* lock mutex for update of global data and output */
-          pthread_mutex_lock(&mutex_output);
+          xpthread_mutex_lock(&mutex_output);
 
           /* show progress */
           progress_update(progress);
 
-          pthread_mutex_unlock(&mutex_output);
+          xpthread_mutex_unlock(&mutex_output);
         }
       else
         {
-          pthread_mutex_unlock(&mutex_input);
+          xpthread_mutex_unlock(&mutex_input);
           break;
         }
     }
@@ -536,8 +536,8 @@ void sintax_thread_worker_run()
 {
   /* initialize threads, start them, join them and return */
 
-  pthread_attr_init(&attr);
-  pthread_attr_setdetachstate(&attr, PTHREAD_CREATE_JOINABLE);
+  xpthread_attr_init(&attr);
+  xpthread_attr_setdetachstate(&attr, PTHREAD_CREATE_JOINABLE);
 
   /* init and create worker threads, put them into stand-by mode */
   for(int t=0; t<opt_threads; t++)
@@ -545,22 +545,20 @@ void sintax_thread_worker_run()
       sintax_thread_init(si_plus+t);
       if (si_minus)
         sintax_thread_init(si_minus+t);
-      if (pthread_create(pthread+t, &attr,
-                         sintax_thread_worker, (void*)(int64_t)t))
-        fatal("Cannot create thread");
+      xpthread_create(pthread+t, &attr,
+                      sintax_thread_worker, (void*)(int64_t)t);
     }
 
   /* finish and clean up worker threads */
   for(int t=0; t<opt_threads; t++)
     {
-      if (pthread_join(pthread[t], NULL))
-        fatal("Cannot join thread");
+      xpthread_join(pthread[t], NULL);
       sintax_thread_exit(si_plus+t);
       if (si_minus)
         sintax_thread_exit(si_minus+t);
     }
 
-  pthread_attr_destroy(&attr);
+  xpthread_attr_destroy(&attr);
 }
 
 void sintax()
@@ -617,8 +615,8 @@ void sintax()
   pthread = (pthread_t *) xmalloc(opt_threads * sizeof(pthread_t));
 
   /* init mutexes for input and output */
-  pthread_mutex_init(&mutex_input, NULL);
-  pthread_mutex_init(&mutex_output, NULL);
+  xpthread_mutex_init(&mutex_input, NULL);
+  xpthread_mutex_init(&mutex_output, NULL);
 
   /* run */
 
@@ -636,8 +634,8 @@ void sintax()
 
   /* clean up */
 
-  pthread_mutex_destroy(&mutex_output);
-  pthread_mutex_destroy(&mutex_input);
+  xpthread_mutex_destroy(&mutex_output);
+  xpthread_mutex_destroy(&mutex_input);
 
   xfree(pthread);
   xfree(si_plus);
