@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2019, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2020, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -78,7 +78,7 @@ class xstring
   ~xstring()
     {
       if (alloc > 0)
-        free(string);
+        xfree(string);
       alloc = 0;
       string = 0;
       length = 0;
